@@ -31,24 +31,42 @@ PDF::Template::Element::HorizontalRule
 
 =head1 PURPOSE
 
+To create a horizontal rule across the page
+
 =head1 NODE NAME
 
+HR
+
 =head1 INHERITANCE
 
+PDF::Template::Element::Line
+
 =head1 ATTRIBUTES
 
 =head1 CHILDREN
 
+None
+
 =head1 AFFECTS
 
+Nothing
+
 =head1 DEPENDENCIES
 
+None
+
 =head1 USAGE
 
+  <hr/>
+
+That will create a line across the page at the current Y-position.
+
 =head1 AUTHOR
 
-Rob Kinyon (rkinyon@columbus.rr.com)
+Rob Kinyon (rob.kinyon@gmail.com)
 
 =head1 SEE ALSO
 
+LINE
+
 =cut
