@@ -9,16 +9,12 @@ BEGIN {
     use PDF::Template::Element;
 }
 
-sub new_unused
+sub new
 {
     my $class = shift;
     my $self = $class->SUPER::new(@_);
 
-#GGG Currently unused
-#    for (qw/ALIGN VALIGN/)
-#    {
-#        $self->{$_} = uc $self->{$_} if defined $self->{$_};
-#    }
+    $self->{TXTOBJ} = PDF::Template::Factory->create('TEXTOBJECT');
 
     return $self;
 }
@@ -38,7 +34,8 @@ sub begin_page
         $self->{TXTOBJ}->resolve($context) ||
         die "Image does not have a filename", $/;
 
-    unless ($context->retrieve_image($txt))
+    my $image = $context->retrieve_image($txt);
+    unless ($image)
     {
         # automatically resolve type if extension is obvious and type was not specified
         my $type = $context->get($self, 'TYPE');
@@ -54,18 +51,18 @@ sub begin_page
         $type = lc $type;
         $type = $convertImageType{$type} if exists $convertImageType{$type};
 
-        my $image = pdflib_pl::PDF_open_image_file($context->{PDF}, $type, $txt, '', 0);
+        $image = pdflib_pl::PDF_open_image_file($context->{PDF}, $type, $txt, '', 0);
         $image == -1 and die "Cannot open <image> file '$txt'", $/;
 
         $context->store_image($txt, $image);
-
-        $self->{IMAGE_HEIGHT} = pdflib_pl::PDF_get_value($context->{PDF}, 'imageheight', $image);
-        $self->{IMAGE_WIDTH}  = pdflib_pl::PDF_get_value($context->{PDF}, 'imagewidth', $image);
-
-        die "Image '$txt' has 0 (or less) height.", $/ if $self->{IMAGE_HEIGHT} <= 0;
-        die "Image '$txt' has 0 (or less) width.", $/  if $self->{IMAGE_WIDTH} <= 0;
     }
 
+    $self->{IMAGE_HEIGHT} = pdflib_pl::PDF_get_value($context->{PDF}, 'imageheight', $image);
+    $self->{IMAGE_WIDTH}  = pdflib_pl::PDF_get_value($context->{PDF}, 'imagewidth', $image);
+
+    die "Image '$txt' has 0 (or less) height.", $/ if $self->{IMAGE_HEIGHT} <= 0;
+    die "Image '$txt' has 0 (or less) width.", $/  if $self->{IMAGE_WIDTH} <= 0;
+
     return 1;
 }
 
@@ -237,7 +234,7 @@ the current X/Y position.
 
 =head1 AUTHOR
 
-Rob Kinyon (rkinyon@columbus.rr.com)
+Rob Kinyon (rob.kinyon@gmail.com)
 
 =head1 SEE ALSO
 
